{%extends module + ":baseChartOptionsDialogBody.html"%}
{%block aggField%}
<div class="col-sm-4" style="padding: 0px 0px 0px 5px;">
	<div class="form-group">
		<label>Aggregation:</label>
		<select class="form-control" name="aggregation" style="margin-left: 0px;">
			<option value="None" selected>None</option>
			{%for aggregationOption in aggregationOptions%}
			<option value="{{aggregationOption}}"{{' selected' if this.options.get("aggregation") == aggregationOption}}>{{aggregationOption}}</option>
			{%endfor%}
		</select>
	</div>
</div>
{%endblock%}
{%block customFormFields%}
<div class="col-sm-4" style="padding: 0px 0px 0px 5px;">
	<div class="form-group">
		<label class="field">Bar Chart Type</label>
		<select class="form-control" name="stacked" style="margin-left: 0px;">
			<option value="true">Stacked</option>
			<option value="false"{{' selected' if this.options.get("stacked") == "false"}}>Grouped</option>
		</select>
	</div>
</div>
{%endblock%}